export { configUser as config };
export { getServerConfig };
export type { ConfigUser };
export type { ConfigResolved };
/** Telefunc Server Configuration */
type ConfigUser = {
    /**
     * The Telefunc HTTP endpoint URL, e.g. `/api/_telefunc`.
     *
     * @default /_telefunc
     *
     * https://telefunc.com/telefuncUrl
     */
    telefuncUrl?: string;
    /** See https://telefunc.com/event-based#naming-convention */
    disableNamingConvention?: boolean;
    /** Your `.telefunc.js` files */
    telefuncFiles?: string[];
    /** Your project root directory, e.g. `/home/alice/code/my-app/` */
    root?: string;
    /** Whether to disable ETag cache headers */
    disableEtag?: boolean;
    /**
     * Whether to generate shield.
     *
     * https://telefunc.com/shield-config
     * https://telefunc.com/shield
     *
     * @default { dev: false, prod: true }
     */
    shield?: {
        dev?: boolean;
        prod?: boolean;
    } | boolean;
    log?: {
        /** Whether to log shield errors */
        shieldErrors?: boolean | {
            /** Whether to log shield errors in production */
            prod?: boolean;
            /** Whether to log shield errors in development */
            dev?: boolean;
        };
    };
};
type ConfigResolved = {
    telefuncUrl: string;
    root: string | null;
    disableEtag: boolean;
    telefuncFiles: string[] | null;
    disableNamingConvention: boolean;
    shield: {
        dev: boolean;
        prod: boolean;
    };
    log: {
        shieldErrors: {
            dev: boolean;
            prod: boolean;
        };
    };
};
declare const configUser: ConfigUser;
declare function getServerConfig(): ConfigResolved;
